@@ -66,6 +66,14 @@ class Photo(models.Model):
     def filename(self):
         return os.path.basename(self.image.name)
 
+    def delete(self, *args, **kwargs):
+        # You have to prepare what you need before delete the model
+        storage, path = self.image.storage, self.image.path
+        # Delete the model before the file
+        super(Photo, self).delete(*args, **kwargs)
+        # Delete the file after the model
+        storage.delete(path)
+
     class Meta:
         verbose_name = _(u'Photo')
         verbose_name_plural = _(u'Photos')
