@@ -7,9 +7,10 @@ from StringIO import StringIO
 from datetime import datetime
 
 from django.shortcuts import get_object_or_404, render_to_response
+from django.template.loader import render_to_string
 from django.template import RequestContext
 from django.contrib.auth.decorators import login_required
-from django.http import HttpResponseRedirect
+from django.http import HttpResponse, HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
 from django.core.urlresolvers import reverse_lazy
 from django.shortcuts import redirect
@@ -20,15 +21,25 @@ import forms as myforms
 
 from sorl.thumbnail import get_thumbnail
 from braces.views import LoginRequiredMixin, SuperuserRequiredMixin
+from taggit.models import Tag
 
 from django.conf import settings as conf
 
 from django.views.generic import DetailView, ListView, CreateView
+from django.views.generic.edit import ProcessFormView
 
 from management.commands.mediasync import get_exif, img_rotate
 from forms import PhotoForm
 
-class Photos(ListView):
+
+class TagMixin(object):
+    def get_context_data(self, **kwargs):
+        context = super(TagMixin, self).get_context_data(**kwargs)
+        context['tags'] = Tag.objects.all()
+        return context
+
+
+class Photos(TagMixin, ListView):
 
     template_name = "rgallery/photos.html"
     context_object_name = "photos"
@@ -68,6 +79,41 @@ class PhotosFolder(ListView):
         return context
 
 
+class PhotosTag(ListView):
+
+    template_name = "rgallery/photos.html"
+    model = mymodels.Photo
+    context_object_name = "photos"
+    paginate_by = 100
+
+    def get_queryset(self):
+        return mymodels.Photo.objects.filter(status=1,
+            tags__slug=self.kwargs.get('slug', None)).order_by('-capture_date')
+
+
+class PhotoAddTag(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
+
+    model = mymodels.Photo
+
+    def post(self, request, *args, **kwargs):
+        if self.request.is_ajax() and self.request.method == 'POST':
+            pk = json.loads(self.request.POST.get('pk', None))
+            tags = json.loads(self.request.POST.get('tags', None))
+            photo = get_object_or_404(mymodels.Photo, pk=pk)
+            photo.tags.clear()
+            if len(tags) > 0:
+                for tag in tags:
+                    try:
+                        t = Tag.objects.get(slug=tag)
+                        photo.tags.add(t)
+                    except:
+                        photo.tags.add(tag)
+            photo.save()
+            rendered = render_to_string('rgallery/_listags.html',
+                                        {'record': photo.tags.all()})
+        return HttpResponse(rendered);
+
+
 class PhotoAdd(LoginRequiredMixin, SuperuserRequiredMixin, CreateView):
 
     model = mymodels.Photo
